struct FreqRange{T}
    range::T
end
function FreqRange(; min, max)
    return FreqRange(min:max)
end
Base.first(r::FreqRange) = first(r.range)
Base.last(r::FreqRange) = last(r.range)


@with_kw struct DispersionModel{S<:AbstractSusceptibility}
    inf = 1.0
    susceptibilities::Vector{S}
    valid_freq_range::FreqRange
end

function eval_dispersion_model(m::DispersionModel, f)
    f_min = first(m.valid_freq_range)
    f_max = last(m.valid_freq_range)
    if !(f_min ≤ f ≤ f_max)
        throw("frequency outside the model valid range $(f_min):$(f_max)")
    end
    val = m.inf
    for sus in m.susceptibilities
        val += eval_susceptibility(sus, f)
    end
    return val
end