abstract type ExcitationType end


@with_kw struct Harmonic <: ExcitationType
    f₀
    smoothing = t -> tanh(t / (f₀))
    amplitude = 1.0
end
function (signal::Harmonic)(t)
    @unpack f₀, smoothing, amplitude = signal
    ω₀ = 2π * f₀
    amplitude * exp(-im * (ω₀ * t)) * smoothing(t)
end
@with_kw struct Gaussian <: ExcitationType
    f₀
    Δf
    t₀ = 2 * inv(Δf)
    amplitude = 1.0
end
function (signal::Gaussian)(t)
    @unpack f₀, Δf, t₀, amplitude = signal
    ω₀ = 2π * f₀
    σₜ = 1 / (2π * Δf)
    amplitude * exp(-0.5((t - t₀) * inv(σₜ))^2) * exp(-im * (ω₀ * t))
end
